==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebRowExportingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowExportingEventArgsDetailDescriptionMetadata } from "./WebRowExportingEventArgsDetailDescriptionMetadata";
import { WebRowExportingEventArgsDescription } from "./WebRowExportingEventArgsDescription";
/**
 * @hidden
 */
export let WebRowExportingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowExportingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowExportingEventArgsDescriptionMetadata.a == null) {
                WebRowExportingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowExportingEventArgsDescriptionMetadata.c(WebRowExportingEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebRowExportingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebRowExportingEventArgsDescriptionMetadata.a);
            WebRowExportingEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowExportingEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebRowExportingEventArgsDetail");
        }
        static d(a) {
            WebRowExportingEventArgsDescriptionMetadata.b(a);
            a.aa("WebRowExportingEventArgs", () => new WebRowExportingEventArgsDescription());
            a.z("WebRowExportingEventArgs", WebRowExportingEventArgsDescriptionMetadata.a);
        }
    }
    WebRowExportingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowExportingEventArgsDescriptionMetadata, 'WebRowExportingEventArgsDescriptionMetadata');
    WebRowExportingEventArgsDescriptionMetadata.a = null;
    return WebRowExportingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebRowExportingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowExportingEventArgsDetailDescriptionMetadata } from "./WebRowExportingEventArgsDetailDescriptionMetadata";
import { WebRowExportingEventArgsDescription } from "./WebRowExportingEventArgsDescription";
/**
 * @hidden
 */
export let WebRowExportingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowExportingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowExportingEventArgsDescriptionMetadata.a == null) {
                WebRowExportingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowExportingEventArgsDescriptionMetadata.c(WebRowExportingEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebRowExportingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebRowExportingEventArgsDescriptionMetadata.a);
            WebRowExportingEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowExportingEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebRowExportingEventArgsDetail");
        }
        static d(a) {
            WebRowExportingEventArgsDescriptionMetadata.b(a);
            a.ac("WebRowExportingEventArgs", () => new WebRowExportingEventArgsDescription());
            a.ab("WebRowExportingEventArgs", WebRowExportingEventArgsDescriptionMetadata.a);
        }
    }
    WebRowExportingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowExportingEventArgsDescriptionMetadata, 'WebRowExportingEventArgsDescriptionMetadata');
    WebRowExportingEventArgsDescriptionMetadata.a = null;
    return WebRowExportingEventArgsDescriptionMetadata;
})();
